# Load the LionBridge assembly

# get the directory of this script file
$currentDirectory = Split-Path (Get-Project).FileName

# get the full path and file name of the App.config file in the same directory as this script
$webConfigFile = [IO.Path]::Combine($currentDirectory, 'web.config')

# initialize the xml object
$webConfig = New-Object XML
# load the config file as an xml object
$webConfig.Load($webConfigFile)

# Read connection string
$connectionString= $webConfig.configuration.connectionStrings.add | ? {$_.name -eq 'EPiServerDB'}

function Remove-LionbridgeConnector() {
	# DELETE LionbridgeConnector dlls EPiServer framework can not sync content types back to database
	if([System.IO.File]::Exists((Split-Path (Get-Project).FileName) + "\bin\LionBridgeConnector.Common.dll"))
	{
		remove-item ((Split-Path (Get-Project).FileName) + "\bin\LionBridgeConnector.Common.dll")
	}

	if([System.IO.File]::Exists((Split-Path (Get-Project).FileName) + "\bin\LionBridgeConnector.Episerver.dll"))
	{
		remove-item ((Split-Path (Get-Project).FileName) + "\bin\LionBridgeConnector.Episerver.dll")
	}

    # Call LionBridge code to clean workspace
    "Attempting to clean up LionbridgeConnector workspace"
	$sqlRemoval = "
	-- Delete scheduled jobs
	DELETE FROM tblScheduledItemLog  
	WHERE fkScheduledItemId IN(  
	SELECT pkID FROM tblScheduledItem WHERE AssemblyName='LionbridgeConnector.EPiServer')  
   
	DELETE FROM tblScheduledItem WHERE AssemblyName='LionbridgeConnector.EPiServer'

	-- DELETE FROM workcontent property
	DELETE FROM tblWorkContentProperty
	WHERE fkPropertyDefinitionID IN(
	SELECT F1.pkid FROM tblPropertyDefinition F1 
	INNER JOIN tblContentType F2 on F1.fkContentTypeID = F2.pkID
	WHERE f2.ModelType LIKE '%Lionbridge.Translate%')

	-- DELETE FROM content property
	DELETE FROM tblContentProperty
	WHERE fkPropertyDefinitionID IN(
	SELECT F1.pkid FROM tblPropertyDefinition F1 
	INNER JOIN tblContentType F2 on F1.fkContentTypeID = F2.pkID
	WHERE f2.ModelType LIKE '%Lionbridge.Translate%')


	-- Delete tblPropertyDefinition
	DELETE FROM tblPropertyDefinition
	WHERE fkContentTypeID IN(SELECT pkID FROM tblContentType WHERE ModelType LIKE '%Lionbridge.Translate%')

    -- Delete from tblContentLanguage
    DELETE FROM tblContentLanguage
    WHERE fkContentID IN(
    SELECT F1.pkId FROM tblContent F1
    INNER JOIN tblContentType F2 ON F1.fkContentTypeID = F2.pkID
    WHERE F2.ModelType LIKE  '%Lionbridge.Translate%'
    )

	-- DELETE FROM tblworkcontent
	DELETE FROM 
	tblWorkContent
	WHERE fkContentID IN(
	SELECT F2.pkId FROM tblContent F2
	INNER JOIN tblContentType F3 ON F2.fkContentTypeID = F3.pkID
	WHERE ModelType LIKE '%Lionbridge.Translate%')

	-- DELETE FROM tblContentSoftlink
	 DELETE FROM tblContentSoftlink WHERE fkOwnerContentID
	 IN(
	 select f2.pkId FROM tblContent F2
	 INNER JOIN tblContentType F3 ON F3.pkID = F2.fkContentTypeID
	 WHERE F3.ModelType LIKE '%Lionbridge%'
	 )

	-- DELETE FROM tblcontent
	DELETE FROM tblContent
	WHERE fkContentTypeID IN(SELECT pkID FROM tblContentType WHERE ModelType LIKE '%Lionbridge.Translate%')

	-- Delete LionBridge.Translate content types
	DELETE FROM tblContentType
	WHERE ModelType LIKE '%Lionbridge.Translate%'"

    $scon = New-Object System.Data.SqlClient.SqlConnection
    $scon.ConnectionString = $connectionString.connectionString
    
    $cmd = New-Object System.Data.SqlClient.SqlCommand
    $cmd.Connection = $scon
    $cmd.CommandText = $sqlRemoval
    $cmd.CommandTimeout = 0
    
    $scon.Open()
    $cmd.ExecuteNonQuery()
    $scon.Dispose()
    $cmd.Dispose()

    # Uninstall the package
	"Attempting to remove LionbridgeConnector Package & it dependencies from the project"
    Uninstall-Package LionbridgeConnector
}

Export-ModuleMember Remove-LionbridgeConnector